summaryrefslogtreecommitdiff
path: root/src/kernel/kernel.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/kernel.c')
-rw-r--r--src/kernel/kernel.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/kernel/kernel.c b/src/kernel/kernel.c
index d74e031..9557745 100644
--- a/src/kernel/kernel.c
+++ b/src/kernel/kernel.c
@@ -31,7 +31,7 @@ static bool terminate = false;
// also elimiate all the object allocated on the stack in kernel_main
static driver_manager_t *global_driver_manager;
// must be first entry in kernel.bin (0x8400) as stage 2 of
// the boot loader expects the entry point to be here!
void kernel_main( void )
{
@@ -51,7 +51,8 @@ void kernel_main( void )
// initialize the early console of the kernel
stdio_set_console( &console );
puts( "Started early kernel console" );
- printf( "Kernel code and data is at 0x%X, kernel stack at 0x%X\n", 0x8400, 0x90000 );
+ // TODO: get those values somehow from the boot loader
+ printf( "Kernel code and data is at 0x%X, kernel stack at 0x%X\n", 0x8800, 0x90000 );
// exit point in case of kernel panic, do this as soon as
// possible, as soon we have an early console we can croak on
@@ -31,7 +31,7 @@ static bool terminate = false;
// also elimiate all the object allocated on the stack in kernel_main
static driver_manager_t *global_driver_manager;
-// must be first entry in kernel.bin (0x8400) as stage 2 of
+// must be first entry in kernel.bin (0x8800) as stage 2 of
// the boot loader expects the entry point to be here!
void kernel_main( void )